@@ -16,21 +16,29 @@ from ...converter_ir.ir_op import (
     ClipOpr,
     ConcatOpr,
     Conv2dOpr,
+    DivOpr,
     DropoutOpr,
     FlattenOpr,
     GatherOpr,
     GetSubTensorOpr,
+    GetVarShapeOpr,
+    HardSigmoidOpr,
     LstmOpr,
     MatMulOpr,
     MaxPool2dOpr,
     MulOpr,
+    PowOpr,
+    ReduceOpr,
     ReluOpr,
     ReshapeOpr,
     ResizeOpr,
     SigmoidOpr,
     SoftmaxOpr,
+    SqrtOpr,
+    SubOpr,
     TransposeOpr,
     TypeCvtOpr,
+    UnsqueezeOpr,
 )
 
 mge_version = mge.__version__
@@ -118,11 +126,15 @@ class OperatorBaseConverter:
         ):
             if name in map_ir_tensor_2_mge_tensor:
                 inp.append(map_ir_tensor_2_mge_tensor[name])
-                if shape is not None:
+                if (
+                    shape is not None
+                    and len(map_ir_tensor_2_mge_tensor[name].shape) > 0
+                ):
                     mge_shape = map_ir_tensor_2_mge_tensor[name].shape.numpy()
-                    assert (
-                        shape == mge_shape
-                    ).all(), f"ONNX shape Infer mismatch with Mge : {shape}(ONNX) vs {mge_shape}Mge"
+                    if shape:
+                        assert (
+                            shape == mge_shape
+                        ).all(), f"ONNX shape Infer mismatch with Mge : {shape}(ONNX) vs {mge_shape}Mge"
             else:
                 assert (
                     data is not None
@@ -178,8 +190,12 @@ class OperatorBaseConverter:
 
 class SISOConvert(OperatorBaseConverter):
     def check_valid(self, inputs, outputs):
-        assert len(inputs) == 1, "Length of inputs should be 1"
-        assert len(outputs) == 1, "Length of outptus should be 1"
+        assert len(inputs) == 1, "{} Length of inputs should be 1, but {}".format(
+            self, len(inputs)
+        )
+        assert len(outputs) == 1, "{} Length of outptus should be 1, but {}".format(
+            self, len(outputs)
+        )
 
 
 class TISOConvert(OperatorBaseConverter):
@@ -200,18 +216,87 @@ class AddConverter(TISOConvert):
         return F.add(inps[0], inps[1])
 
 
+@_register_op(SubOpr)
+class SubConverter(TISOConvert):
+    def forward(self, inps):
+        return F.sub(inps[0], inps[1])
+
+
+@_register_op(PowOpr)
+class PowConverter(TISOConvert):
+    def forward(self, inps):
+        return F.pow(inps[0], inps[1])
+
+
+@_register_op(SqrtOpr)
+class SqrtConverter(SISOConvert):
+    def forward(self, inps):
+        return F.sqrt(inps[0])
+
+
+@_register_op(DivOpr)
+class DivConverter(TISOConvert):
+    def forward(self, inps):
+        return F.div(inps[0], inps[1])
+
+
+@_register_op(MatMulOpr)
+class MatMulConverter(TISOConvert):
+    def forward(self, inps):
+        return F.matmul(inps[0], inps[1])
+
+
+@_register_param_extract(ReduceOpr)
+class ReduceExtractor:
+    def __init__(self, opr):
+        self._opr = opr
+
+    def extract(self):
+        param = {}
+        param["mode"] = self._opr.mode
+        param["axis"] = self._opr.axis
+        param["keepdims"] = self._opr.keep_dims
+        return param
+
+
+@_register_op(ReduceOpr)
+class ReduceConverer(SISOConvert):
+    def forward(self, inps):
+        func_mode_map = {
+            "MAX": F.max,
+            "MIN": F.min,
+            "MEAN": F.mean,
+            "SUM": F.sum,
+        }
+        op = func_mode_map[self.param["mode"]]
+        axes = self.param["axis"]
+        return op(inps[0], axis=axes, keepdims=self.param["keepdims"])
+
+
 @_register_op(SigmoidOpr)
 class SigmoidConverter(SISOConvert):
     def forward(self, inps):
         return F.nn.sigmoid(inps[0])
 
 
+@_register_op(HardSigmoidOpr)
+class HardSigmoidConverter(SISOConvert):
+    def forward(self, inps):
+        return F.nn.hsigmoid(inps[0])
+
+
 @_register_op(ReluOpr)
 class ReluConverter(SISOConvert):
     def forward(self, inps):
         return F.nn.relu(inps[0])
 
 
+@_register_op(GetVarShapeOpr)
+class GetVarShapeConverter(SISOConvert):
+    def forward(self, inps):
+        return inps[0].shape
+
+
 @_register_param_extract(ReshapeOpr)
 class ReshapeExtractor:
     def __init__(self, opr):
@@ -227,10 +312,12 @@ class ReshapeExtractor:
 
 
 @_register_op(ReshapeOpr)
-class ReshapeConverter(SISOConvert):
+class ReshapeConverter(OperatorBaseConverter):
     def forward(self, inps):
         target_shape = self.param["out_shape"]
-        if 0 not in target_shape and -1 not in target_shape:
+        if target_shape is None:
+            return F.reshape(inps[0], inps[1])
+        elif 0 not in target_shape and -1 not in target_shape:
             return F.reshape(inps[0], target_shape)
         else:
             tshape = []
@@ -503,7 +590,8 @@ class ConcatExtractor:
 @_register_op(ConcatOpr)
 class ConcatConvert(OperatorBaseConverter):
     def forward(self, inps):
-        return F.concat(inps, self.param["axis"])
+        x = F.concat(inps, self.param["axis"])
+        return x
 
 
 @_register_param_extract(DropoutOpr)
@@ -723,16 +811,38 @@ class GatherExtractor:
         return {"axis": opr.axis}
 
 
+@_register_param_extract(UnsqueezeOpr)
+class UnsqueezeOprExtractor:
+    def __init__(self, opr):
+        self._opr = opr
+
+    def extract(self):
+        param = {}
+        param["squeeze_dims"] = self._opr.squeeze_dims
+        return param
+
+
+@_register_op(UnsqueezeOpr)
+class UnsqueezeOprConvert(SISOConvert):
+    def forward(self, inps):
+        dims = self.param["squeeze_dims"]
+        return F.expand_dims(inps[0], dims)
+
+
 @_register_op(GatherOpr)
 class GatherConvert(TISOConvert):
     def forward(self, inps):
-        indices_shape = inps[1].shape.numpy()
-        if inps[0].ndim == 2 and inps[1].ndim == 1:
-            if self.param["axis"] == 0:
-                x = F.reshape(inps[1], [indices_shape[0], 1])
-            else:
-                assert self.param["axis"] == 1
-                x = F.reshape(inps[1], [1, indices_shape[0]])
-            return F.gather(inps[0], self.param["axis"], x)
-        else:
-            return F.gather(inps[0], self.param["axis"], inps[1])
+        indics = inps[1].numpy()
+        axes = self.param["axis"]
+        assert len(indics.shape) == 0
+        x = inps[0]
+        dims = len(x._tuple_shape)
+        index = int(indics)
+        sub_indics = [
+            slice(index, index + 1, None) if i == axes else slice(None, None, None)
+            for i in range(dims)
+        ]
+        sub_indics = tuple(sub_indics)
+        x = inps[0][sub_indics]
+        x = F.squeeze(x, axis=axes)
+        return x
