@@ -48,6 +48,7 @@ from .ir_op import (
     TanHOpr,
     TransposeOpr,
     TrueDivOpr,
+    _ConvOpr,
     _PoolOpr,
 )
 from .ir_tensor import AxisOrder, IRTensor
@@ -119,6 +120,9 @@ class TransformerRule(Enum):
     RENAME_CAFFE_LAYER_TENSOR = 132
 
     TRANSPOSE_LINEAR_WEIGHT_TO_NHWC = 133
+    # force fc with no trans for megengine
+    FC_NO_TRANS = 134
+    BIAS_ASTYPE_INT64 = 135
 
 
 def cmp_rules(a, b):
@@ -1510,3 +1514,54 @@ def _convert_linear_weight_to_NHWC(net: IRGraph):
             # flatten weight
             data = np.reshape(data, [data.shape[0], -1])
             weight.np_data = data
+
+
+# FIXME: change onnx fe ir np_data use np.array from bytes
+@_register_tranformation_rule(TransformerRule.FC_NO_TRANS)
+def matmul_no_trans(graph: IRGraph):
+    def get_numpy(tensor):
+        return np.frombuffer(tensor.np_data, dtype=tensor.dtype).reshape(tensor.shape)
+
+    def trans_tensor(tensor):
+        np_data = get_numpy(tensor)
+        np_data = np.ascontiguousarray(np_data.transpose([1, 0]))
+        tensor.shape = np_data.shape
+        tensor.np_data = np_data.tobytes()
+
+    for opr in graph.all_oprs:
+        if isinstance(opr, MatMulOpr):
+            tensor_a = opr.inp_tensors[0]
+            tensor_b = opr.inp_tensors[1]
+            if opr.transpose_a and tensor_a.owner_opr == None:
+                opr.transpose_a = False
+                trans_tensor(tensor_a)
+
+            if opr.transpose_b and tensor_b.owner_opr == None:
+                opr.transpose_b = False
+                trans_tensor(tensor_b)
+
+
+@_register_tranformation_rule(TransformerRule.BIAS_ASTYPE_INT64)
+def _bias_astype_int64(net: IRGraph):
+    for opr in net.all_oprs:
+        if not isinstance(opr, (MatMulOpr, _ConvOpr)):
+            continue
+        bias = None
+        if isinstance(opr, MatMulOpr) and len(opr.inp_tensors) == 3:
+            bias = opr.inp_tensors[2]
+        elif isinstance(opr, Deconv2dOpr) and len(opr.inp_tensors) > 3:
+            if (
+                opr.inp_tensors[0].shape == [4] and len(opr.inp_tensors) == 4
+            ):  # shape as input
+                bias = opr.inp_tensors[-1]
+            if len(opr.inp_tensors) == 4:
+                bias = opr.inp_tensors[-1]
+        elif isinstance(opr, (Conv2dOpr, ConvRelu2dOpr)) and len(opr.inp_tensors) == 3:
+            bias = opr.inp_tensors[-1]
+        if bias is not None and bias.scale is not None:
+            bias.set_qparams(
+                scale=bias.scale,
+                zero_point=bias.zero_point,
+                q_dtype="int64",
+                np_dtype="int64",
+            )
